function xdot = Adotfun2017BS(t,x,ton,par)
% Ramsey model with resource
% Integration over time

% tax
on=t>=ton;

% rescaling
k=exp(x(1));
S=x(2)*1000;
c=exp(x(3));
p=x(4);
M=x(5:7);
T=x(8:9);
r=x(10:12);
tau=x(13:14);


% unpack par
alpha=par.alpha; beta=par.beta;delta=par.delta;
rho=par.rho; theta=par.theta; 
b=par.b; epsilon=par.epsilon;
Ehat=par.Ehat; 
ql=par.ql; qu=par.qu; 

lambda1=par.lambda1; 
gamma=par.gamma1;




% Economic model
Omega=1-(par.xi1*T(1)+par.xi2*T(1)^2); 
Rcost=gamma*S^(-epsilon); % extraction costs
q=Rcost+p+on*r(1)*exp(Ehat*t); % resource price
if q<ql
    RperEN=1; % extraction per unit of energy
    GperEN=0; % goods per unit energy
elseif q>qu
    RperEN=0;
    GperEN=(ql+qu)/2;
else
    RperEN=(qu-q)/(qu-ql);
    GperEN=(ql+qu-2*qu*RperEN+(qu-ql)*RperEN^2)/2;
end
pEN=q*RperEN+GperEN; % energy price
cEN=Rcost*RperEN+GperEN; % energy unit cost
y=(b*Omega*(beta/pEN)^beta*k^alpha)^(1/(1-beta)); % gross output per effective labour
ENperE=beta*y/pEN; % energy per effective labour, in GtC
EN=ENperE*exp(Ehat*t);
R=EN*RperEN;
ir=alpha*y/k-delta; % interest rate

khat=(1-beta*cEN/pEN)*y/k-c/k-delta-Ehat;
chat=1/theta*(ir-rho)-Ehat; % KRR per effective labor
Sdot=-R/1000; % note units, R is in GtC, S in Thsd. GtC
pdot=(ir)*p-(R)*epsilon*Rcost/S;

% climate module
El=par.El0*exp(-par.eta3*t);
if t<90
    tf=t/90;
else
    tf=1;
end
Fex=par.Fex0+tf*(par.Fex100-par.Fex0);
Pi=par.eta1*log(M(1)/par.M1750)+par.eta2*Fex;
Mdot=par.Gamma*M+[El+R 0 0]';  % time derivatives of M
Tdot=par.Lambda*T+[Pi 0]'; % time derivatives of T
%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Externalities
rdot=((ir-Ehat)*eye(3)-par.Gamma')*r-[tau(1)*par.eta1/(M(1)) 0 0]';
yT=-y/Omega*(par.xi1+2*par.xi2*T(1));
taudot=((ir-Ehat)*eye(2)-par.Lambda')*tau+[yT 0]';

%%%%%%%%%%%%%%%%%%%%%%%%%%%

xdot=[khat;Sdot;chat;pdot;Mdot;Tdot;rdot;taudot;0;0];
xdot(15)=-ir;
xdot(16)=-c^(1-theta)-lambda1*x(16); % welfare measure
end


