% set exogenous parameters
ExogenousParameters
% now make changes, if wanted... 

ImpliedParameters
%%%%%%%%%%%%%%%%%%%%%%%%%
% some additions and changes because the model is solved in a different way 
% Starters
S0=6; % earth carbon stock, Thsd. GtC
epsilon=1.6; % extraction cost elasticity
fql=2.5; % lower backstop factor
fqu=3.5; % upper backstop factor

% the economy starts (ends) switching to backstop,
%   when the unit extraction cost
%   attains fql (fqu) times the cost at start.

lambda1=(1-theta)*Ehat-rho; % st-st rate of utility growth
sst=alpha*(Ehat+delta)/(ist+delta); % st-st saving rate
% Note: the st-st saving rate is st-st saving per gross-GDP,

q0=beta*Ys0/R0; % start carbon flow unit cost, USD/kg
ql=fql*q0;
qu=fqu*q0;

gamma1=q0*(S0*1000)^epsilon; % scaler for extraction cost, need to rescale because S0 in 6 statt 6000 measured...  
k0=alpha*Ys0/(ist+delta); % capital, E(0)=1
Pi0=par.eta1*log(M0(1)/par.M1750)+par.eta2*par.Fex0;
T1dot=par.Lambda(1,:)*T0+Pi0;

Df0=1-(par.xi1*T0(1)+par.xi2*T0(1)^2); % damage factor at start
b=Df0*Ys0/(k0^alpha*R0^beta); % scaler of prod.function times Df0

% Storing constants in par
par.Ehat=Ehat; 
par.epsilon=epsilon;
par.sst=sst; 
par.gamma1=gamma1;
par.irst=ist;
par.ql=ql; par.qu=qu; par.lambda1=lambda1;
par.b=b;
par.S0=S0;

% find first guess for model 
par.taxtime=tfinal+1; % start with market solution, tax never enacted
tfinal= 550; %Set to 600 for late backstop!
nS=100; % number of meshes for initial guess

% Solow solution
dotfun=@(t,x)solowf2017(t,x,par);
x0=[log(k0); S0; M0; T0; 0]; % k,S,M,T 
Sol=ode15s(dotfun,[0 tfinal],x0);

% Log-linearly approximated feedback
aa=alpha-sst; bb=sst-1; cc=1/theta*alpha*(alpha-1);
z=sqrt(aa*aa+4*bb*cc);
elst=2*cc/(aa-z); % elasticity of consumtion w.r.t. capital
par.elst=elst;

% Ramsey solution, guess
opt=bvpset('Nmax',5000,'RelTol',.1);
Sol3=guess42017(Sol,par);
bfun=@(x0,xend)Abound2017BS(x0,xend,par,k0,M0,T0,S0);

% find market solution
ton=tfinal+1;  
dotfun=@(t,x)Adotfun2017BS(t,x,ton,par);
tic
Sol4 = bvp5c(dotfun,bfun,Sol3,opt);
toc
% slowly increase precision
opt=bvpset('Nmax',8000,'RelTol',.001);
tic
Sol4 = bvp5c(dotfun,bfun,Sol4,opt);
toc
opt=bvpset('Nmax',10000,'RelTol',.00001);
tic
Sol4 = bvp5c(dotfun,bfun,Sol4,opt);
toc

% find complete switsch to backstop technology
Solp4=deval(Sol4,0:tfinal);
tswitsch=find(Solp4(4,:)<=0.000001);
tswitsch(1)
% use this as starting point: easier to solve if we go `backwards' to find
% the critical lag
Ton=[tswitsch(1):-10:71,70:-10:0];
Ugain=[];
Sol5=Sol4;

for ton=Ton;
    dotfun=@(t,x)Adotfun2017BS(t,x,ton,par);
    tic
    Sol5 = bvp5c(dotfun,bfun,Sol5,opt);
    toc
    tic
    Sol5 = bvp5c(dotfun,bfun,Sol5,opt);
    toc
    
    Solp5=deval(Sol5,0:tfinal);
    Ugain=[Ugain 100*((Solp5(16,1)/Solp4(16,1))^((1/theta)/(1/theta-1))-1)];
    
end

z50=find(Ton==50);
z70=find(Ton==70);
z0=find(Ton==0);
Ugain([z0, z50, z70]) 
