% set exogenous parameters
ExogenousParameters
% now make changes, if wanted... 

ImpliedParameters
%%%%%%%%%%%%%%%%%%%%%%%%%
% find first guess for model 
par.taxtime=tfinal+1; % start with market solution, tax never enacted

% do Solow K, C (fixed saving rate)
% with resource stock S that is always used in steady state relation
% and with climate T M
% without prices and utility
y0=[0,0,0,0,0,0,0];
dotfun=@(t,x)optimum2017a(t,x,par);
[t,y] = ode45(dotfun,[0 tfinal],y0,par);
sol45=ode45(dotfun,[0 tfinal],y0,par);

% solve with bvp5c solver
Solin.x=t';
Solin.y=y';
dotfun=@(t,x)optimum2017a(t,x,par);
bfun=@(x0,x1)optbound4b2017a(x0,x1,par);
Sol = bvp5c(dotfun,bfun,Solin); 

% add C
Solin1.x=Sol.x;
nt=length(Solin1.x);
Solin1.y=[Sol.y(1,:); zeros(1,nt);Sol.y(2:7,:)];

dotfun=@(t,x)optimum2017a1(t,x,par);
bfun=@(x0,x1)optbound4b2017a1(x0,x1,par);
Sol = bvp5c(dotfun,bfun,Solin1); 

% add P
Solin2.x=Sol.x;
nt=length(Solin2.x);
Solin2.y=[Sol.y(1:8,:); zeros(5,nt)];

dotfun=@(t,x)optimum2017a2(t,x,par);
bfun=@(x0,x1)optbound4b2017a2(x0,x1,par);
Sol = bvp5c(dotfun,bfun,Solin2); 

% add v
Solin3.x=Sol.x;
nt=length(Solin3.x);
Solin3.y=[Sol.y(1:13,:); zeros(1,nt)];

dotfun=@(t,x)optimum2017a3(t,x,par);
bfun=@(x0,x1)optbound4b2017a3(x0,x1,par);
Sol = bvp5c(dotfun,bfun,Solin3); 

% add p
Solin4.x=Sol.x;
nt=length(Solin4.x);
Solin4.y=[Sol.y(1:14,:); zeros(1,nt)];

dotfun=@(t,x)optimum2017a4(t,x,par);
bfun=@(x0,x1)optbound4b2017a4(x0,x1,par);
Sol = bvp5c(dotfun,bfun,Solin4); 
Sol = bvp5c(dotfun,bfun,Sol); 


%%% now calibrate z (includes b and gamma) 
Solin5.x=Sol.x; Solin5.y=Sol.y; Solin5.parameters=par.zz;
par.zz=[];
dotfun=@(t,x,z)optimum2017a5(t,x,z,par);
bfun=@(x0,x1,z)optbound4b2017a5(x0,x1,z,par);
Sol = bvp5c(dotfun,bfun,Solin5); 

time=linspace(0,tfinal,tfinal+1);
res=evaluation2017(Sol,z,par,time);

% z is now taken as given again!
par.zz=Sol.parameters;

Solin6.x=Sol.x; Solin6.y=Sol.y;

dotfun=@(t,x)optimum2017a4(t,x,par);
bfun=@(x0,x1)optbound4b2017a4(x0,x1,par);
Solm = bvp5c(dotfun,bfun,Solin6);  

options = bvpset('reltol',0.000001);
Solm = bvp5c(dotfun,bfun,Solm,options);  

vIECm=evaluation2017(Solm,par.zz,par,time);

% so far, market solution
% now: optimum
par.taxtime=0;

dotfun=@(t,x)optimum2017a4(t,x,par);
bfun=@(x0,x1)optbound4b2017a4(x0,x1,par);
Sol = bvp5c(dotfun,bfun,Solin6);  
Solo = bvp5c(dotfun,bfun,Sol, options);  
vIECo=evaluation2017(Solo,par.zz,par,time);

% welfare
hMOIEC=((vIECo.v(1)/vIECm.v(1))^(1/(1-par.theta))-1)*100 % >0 implies a higher consumption path is needed 

%%% Window of Opportunity 
% Market with announced intervention at taxtime
Sol=Solm;
taxend=70;

taxtime=[0:taxend];
ntime=length(taxtime);
Effect=zeros(ntime,1);
for j=1:ntime
  j
  par.taxtime=taxtime(j);
  dotfun=@(t,x)optimum2017a4(t,x,par);
  bfun=@(x0,x1)optbound4b2017a4(x0,x1,par);
  Sol = bvp5c(dotfun,bfun,Solm,options);
  Sol = bvp5c(dotfun,bfun,Sol,options);
  vIECt=evaluation2017(Sol,par.zz,par,time);
  Effect(j)=((vIECt.v(1)/vIECm.v(1))^(1/(1-par.theta))-1)*100;
end
EffectIEC=Effect;
xy=find(EffectIEC<0);
%critical lag
xy(1) 
 
figure(1)
% welfare gain and implementation lag in years
plot(taxtime,EffectIEC,'LineWidth',4) 
hold on
plot(taxtime, zeros(size(taxtime)),':','LineWidth',4)
xlabel('Implementation lag in years','fontsize',36)
ylabel('Welfare gain by intervention, \newline percent of consumption','fontsize',36)
set(gca,'fontsize',36)
xlim([0 75])
ylim([-2 12])
hold off

% Temp increase in 2100:
vIECm.T(1,85)
% initial resource price and rent component, and rent-to-ptice ratio
vIECm.q(1)
vIECm.p(1)
vIECm.p(1)/vIECm.q(1)*100

