function Sol3 = guess42017(Sol,par)

% Initial guess from Solow path
b=par.b; epsilon=par.epsilon; theta=par.theta;
sst=par.sst; alpha=par.alpha; beta=par.beta; gamma=par.gamma1;
xi1=par.xi1; xi2=par.xi2; irst=par.irst;
delta=par.delta; Ehat=par.Ehat; 
ql=par.ql; qu=par.qu; lambda1=par.lambda1; 


Sol3.x=Sol.x;
tlength=length(Sol.x);
tend=Sol.x(end);
Sol3.y=zeros(16,tlength);
Sol3.y([1 2 5:9 15],:)=Sol.y;

k=exp(Sol.y(1,:));
S=Sol.y(2,:).*1000;
M1=Sol.y(3,:);
T1=Sol.y(6,:);
T=Sol.y(6:7,:);

Rcost=gamma*S.^(-epsilon); 
q=Rcost; % resource price, here equal to unit extraction cost
phase1=find(q<ql);
phase2=find(q>=ql & q<=qu);
phase3=find(q>qu);
RperEN=zeros(1,tlength);
GperEN=zeros(1,tlength);

RperEN(phase1)=1; % extraction per unit of energy
GperEN(phase1)=0; % goods per unit energy

RperEN(phase2)=(qu-q(phase2))/(qu-ql);
GperEN(phase2)=(ql+qu-2*qu*RperEN(phase2)+(qu-ql)*RperEN(phase2).^2)/2;

RperEN(phase3)=0;
GperEN(phase3)=(ql+qu)/2;

pEN=q.*RperEN+GperEN; % energy price

Pi=par.eta1.*log(M1./par.M1750)+par.eta2*par.Fex0.*ones(size(M1));
Tdot=par.Lambda(1,:)*T+Pi;

Omega=1-(xi1*T1+xi2*T1.^2); % scaler of production function
y=(b.*Omega.*(beta./pEN).^beta.*k.^alpha).^(1/(1-beta)); % gross output per effective labour
c=(1-beta-sst)*y;
Sol3.y(3,:)=log(c);

dotfun=@(t,p)backp(t,p,Sol,par);
Solp=ode15s(dotfun,[tend 0],0);
Sol3.y(4,:)=deval(Solp,Sol.x);

T=Sol.y(6:7,end);
M=Sol.y(3:5,end);
qend=(ql+qu)/2;

Pi=par.eta1*log(M(1)/par.M1750)+par.eta2*par.Fex0;
Tdot=par.Lambda(1,:)*T+Pi;
Omega=1-(xi1*T(1)+xi2*T(1)^2);
A=(irst+delta)/alpha;
B=Omega*b*(beta/qend)^beta;
kst=(B/(A^(1-beta)))^(1/(1-beta-alpha));
yst=A*kst;
yTst=-yst/Omega*(xi1+2*xi2*T(1));
taust=-((irst-Ehat)*eye(2)-par.Lambda')\[yTst 0]';
rst=((irst-Ehat)*eye(3)-par.Gamma')\[taust(1)*par.eta1/(M(1)) 0 0]';
cst=(1-beta-sst)*yst;

Sol3.y(10:12,:)=rst*ones(1,tlength);
Sol3.y(13:14,:)=taust*ones(1,tlength);
Sol3.y(16,:)=(-1/lambda1)*cst^(1-theta)*ones(1,tlength);
end

function pdot=backp(t,p,Sol,par)

b=par.b; Ehat=par.Ehat; delta=par.delta; epsilon=par.epsilon;
rho=par.rho; alpha=par.alpha; beta=par.beta; gamma=par.gamma1;
theta=par.theta;
xi1=par.xi1; xi2=par.xi2;
ql=par.ql; qu=par.qu; 

x=deval(Sol,t);
k=exp(x(1));
S=x(2).*1000;
T1=x(6);
T=x(6:7);
M1=x(3);

Rcost=gamma*S^(-epsilon);
q=Rcost; % resource price, here equal to unit extraction cost
if q<ql
    RperEN=1; % extraction per unit of energy
    GperEN=0; % goods per unit energy
elseif q>qu
    RperEN=0;
    GperEN=(ql+qu)/2;
else
    RperEN=(qu-q)/(qu-ql);
    GperEN=(ql+qu-2*qu*RperEN+(qu-ql)*RperEN^2)/2;
end
pEN=q*RperEN+GperEN; % energy price

Pi=par.eta1*log(M1/par.M1750)+par.eta2*par.Fex0;
Tdot=par.Lambda(1,:)*T+Pi;

Omega=1-(xi1*T1+xi2*T1^2); % scaler of production function
y=(b*Omega*(beta/pEN)^beta*k^alpha)^(1/(1-beta)); % gross output per effective labour
ENperE=beta*y/pEN; % energy per effective labour, in GtC
EN=ENperE*exp(Ehat*t);
R=EN*RperEN;
ir=alpha*y/k-delta; % interest rate
pdot=(ir)*p-(R)*epsilon*q/S;
end



