function xdot = solowf2017(t,x,par)
% Solow model with resource and backstop


b=par.b; Ehat=par.Ehat; delta=par.delta;
epsilon=par.epsilon;
sst=par.sst; alpha=par.alpha; beta=par.beta; gamma=par.gamma1;
xi1=par.xi1; xi2=par.xi2; ql=par.ql; qu=par.qu;

k=exp(x(1));
S=x(2).*1000;
M=x(3:5);
T=x(6:7);

% Economic model

xdot=zeros(8,1); % k,S,M,T,D. Note that c and p are missing
%Rcost=mu*S^(-epsilon);
Rcost=gamma*S^(-epsilon);
q=Rcost; % resource price, here equal to unit extraction cost
if q<ql
    RperEN=1; % extraction per unit of energy
    GperEN=0; % goods per unit energy
elseif q>qu
    RperEN=0;
    GperEN=(ql+qu)/2;
else
    RperEN=(qu-q)/(qu-ql);
    GperEN=(ql+qu-2*qu*RperEN+(qu-ql)*RperEN^2)/2;
end
pEN=q*RperEN+GperEN; % energy price

% Climate model first part %%%%%%%%%%%%%%%%%%%%%%%
Gamma=par.Gamma;
Lambda=par.Lambda;
eta1=par.eta1; % effect of log-M-ratio on Pi
eta2=par.eta2; % effect of Fex on Pi
eta3=par.eta3; % rate of decline (>0) of El
El0=par.El0; % starter of El
M1750=par.M1750; % M1 in 1750
Fex0=par.Fex0; % starter of Fex
Fex100=par.Fex100; % final of Fex

El=El0*exp(-eta3*t);

if t<90
    tf=t/90;
else
    tf=1;
end

Fex=Fex0+tf*(Fex100-Fex0);
Pi=eta1*log(M(1)/M1750)+eta2*Fex;
Tdot=Lambda*T+[Pi 0]'; % time derivatives of T

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Omega=1-(xi1*T(1)+xi2*T(1)^2); % scaler of production function
y=(b*Omega*(beta/pEN)^beta*k^alpha)^(1/(1-beta)); % gross output per effective labour

ENperE=beta*y/pEN; % energy per effective labour, in GtC
EN=ENperE*exp(Ehat*t);
R=EN*RperEN;
khat=sst*y/k-delta-Ehat;
ir=alpha*y/k-delta;
xdot(8)=-ir;
Sdot=-R/1000; % note units, R is in GtC, S in Thsd. GtC
xdot(1)=khat; % capital
xdot(2)=Sdot; % carbon stock in earth

% climate part 2
Mdot=Gamma*M+[El+R 0 0]';%/1000; % time derivatives of M
xdot(3:5)=Mdot;
xdot(6:7)=Tdot;
end

